@@ -1,6 +1,7 @@
 import itertools
 import json
 import pathlib
+import sys
 from collections import defaultdict
 from typing import Any
 from typing import Callable
@@ -8,12 +9,15 @@ from typing import Dict
 from typing import List
 from typing import Tuple
 from typing import Union
+from pathlib import Path
 
 
 try:
+    from importlib.abc import Traversable
     from importlib.resources import files
 except ImportError:
     from importlib_resources import files  # type: ignore
+    from importlib_resources.abc import Traversable  # type: ignore
 
 
 _registry: Dict[str, Union[Dict, List[Dict]]] = {}
@@ -41,10 +45,15 @@ def has(name: str) -> bool:
 def get(name: str) -> Union[Dict, List[Dict]]:
     if not has(name):
         data = None
-        directory = files(__package__) / f"{name}_registry"
+        package_path: Union[Traversable, Path]
+        if getattr(sys, "frozen", False) and hasattr(sys, "_MEIPASS"):
+            package_path = Path(getattr(sys, "_MEIPASS"))
+        else:
+            package_path = files(__package__)
+        directory = package_path / f"{name}_registry"
         assert isinstance(directory, pathlib.Path)
         for entry in sorted(directory.glob("*.json")):
-            with entry.open() as fp:
+            with entry.open(encoding="utf-8") as fp:
                 chunk = json.load(fp)
                 if data is None:
                     data = chunk
